Clean up the last few deprecation warnings in the tests


git-svn-id: https://svn.apache.org/repos/asf/incubator/thrift/trunk@668922 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/test/rb/core/transport/test_ttransport.rb b/test/rb/core/transport/test_ttransport.rb
index bb876dc..366389b 100644
--- a/test/rb/core/transport/test_ttransport.rb
+++ b/test/rb/core/transport/test_ttransport.rb
@@ -18,8 +18,8 @@
     @trans = TTransport.new
   end
   
-  def test_is_open?
-    assert_nil @trans.is_open?
+  def test_open?
+    assert_nil @trans.open?
   end
   
   def test_open
@@ -37,12 +37,12 @@
   # TODO:
   # This doesn't necessarily test he right thing.
   # It _looks_ like read isn't guarenteed to return the length
   # you ask for and readAll is. This means our test needs to check
   # for blocking. -- Kevin Clark 3/27/08
   def test_read_all
     # Implements read
     t = DummyTransport.new("hello")
-    assert_equal "hello", t.readAll(5)
+    assert_equal "hello", t.read_all(5)
   end
   
   def test_write
@@ -59,13 +59,13 @@
     @trans = TTransport.new
   end
   
-  def test_isOpen
-    assert_nil @trans.isOpen
+  def test_open?
+    assert_nil @trans.open?
   end
     
   def test_readAll
     # Implements read
     t = DummyTransport.new("hello")
-    assert_equal "hello", t.readAll(5)
+    assert_equal "hello", t.read_all(5)
   end
 end
\ No newline at end of file
@@ -37,12 +37,12 @@
   # This doesn't necessarily test he right thing.
   # It _looks_ like read isn't guarenteed to return the length
-  # you ask for and readAll is. This means our test needs to check
+  # you ask for and read_all is. This means our test needs to check
   # for blocking. -- Kevin Clark 3/27/08
   def test_read_all